@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.019000';
+our $VERSION = '2.020000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -70,7 +70,9 @@ has 'plugins' => ( 'is' => 'ro' =>, 'isa' => 'ArrayRef', 'init_arg' => undef, 'l
 
 
 
-has 'normal_form' => ( 'is' => ro =>, 'isa' => 'Str', 'required' => 1 );    #builder => sub { 'numify' } );
+
+
+has 'normal_form' => ( 'is' => ro =>, 'isa' => 'Str', lazy => 1, builder => sub { 'numify' } );
 
 
 
@@ -87,11 +89,6 @@ has 'mantissa' => (
   'isa'     => 'Int',
   'lazy'    => 1,
   'builder' => sub {
-    my ($self) = @_;
-    if ( 'numify' eq $self->normal_form ) {
-      require Carp;
-      return Carp::croak('mantissa required but not specified');
-    }
     return 6;
   },
 );
@@ -114,8 +111,7 @@ has 'mantissa' => (
 
 
 
-
-has 'git_versions' => ( is => 'ro', isa => enum( [1] ), required => 1, );
+has 'git_versions' => ( is => 'ro', isa => 'Any', lazy => 1, default => sub { undef } );
 
 
 
@@ -674,14 +670,11 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.019000
+version 2.020000
 
 =head1 SYNOPSIS
 
     [@Author::KENTNL]
-    git_versions = 1      ; Mandatory flag indicating the dist is adjusted to use git tag versioning
-                          ; otherwise use an older bundle version.
-
     normal_form  = numify ; Mandatory for this bundle indicating normal form.
                           ; see DZP::Git::NextVersion::Sanitized
 
@@ -793,15 +786,17 @@ Populated during C<< $self->configure >> and returned from C<< ->bundle_config >
 
 =head2 C<normal_form>
 
-  Str, ro, required
+  Str, ro, lazy
 
 A C<normal_form> to pass to L<< C<[Git::NextVersion::Sanitized]>|Dist::Zilla::Plugin::Git::NextVersion::Sanitized >>.
 
+Defaults to C<numify>
+
 See L<< C<[::Role::Version::Sanitize]>|Dist::Zilla::Role::Version::Sanitize >>
 
 =head2 C<mantissa>
 
-  Int, ro, required if normal_form eq 'numify'
+  Int, ro, defaults to 6.
 
 Defines the length of the mantissa when normal form is C<numify>.
 
@@ -809,20 +804,19 @@ See L<< C<[Git::NextVersion::Sanitized]>|Dist::Zilla::Plugin::Git::NextVersion::
 
 =head2 C<git_versions>
 
-  enum([1]), ro, required
+  Any, unused.
 
 =over 4
 
-=item * B<MUST BE SPECIFIED>
-
-=item * B<< MUST BE C<1> >>
+=item * B<UNUSED>
 
 =back
 
-Setting as such indicates that the distribution in question is safe to use with C<Git::NextVersion>.
+Since C<2.020>, this field is no longer required, and is unused, simply supported for legacy reasons.
 
-As no logic exists any more to support using anything other than C<Git::NextVersion> with this bundle,
-this parameter must be turned on and you must use Git::NextVersion.
+Things may not work if code has not been portaged to be C<Git::NextVersion> safe, but that's better than going "bang".
+
+But code will be assumed to be using C<Git::NextVersion>.
 
 =head2 C<authority>
 
